@@ -50,9 +50,9 @@ sub delete {
 
 sub update {
     my ($self, $key, $value) = @_;
-    
+
 }
-    
+
 sub clear {
     my ($self) = @_;
 
@@ -65,13 +65,12 @@ sub purge {
 
 sub incr {
     my ($self, $key) = @_;
-    
 
 }
 
 sub decr {
     my ($self, $key) = @_;
-    
+
 }
 
 # ----------------------------------------------------------------------
@@ -84,7 +83,7 @@ __END__
 
 =head1 NAME
 
-Scaffold::Cache - A base class for Cache Management in Scaffold
+Scaffold::Cache - The base class for Caching in Scaffold
 
 =head1 SYNOPSIS
 
@@ -96,64 +95,64 @@ Scaffold::Cache - A base class for Cache Management in Scaffold
 
 =head1 DESCRIPTION
 
-The Scaffold environment uses caching by default. If no "cache" engine is 
-defined, it will use Scaffold::Cache::FastMmap with reasonable, built in 
-defaults. The caching subsystem is used by several of the Scaffold modules. 
-This is done for performance reasons. i.e. it is usaully faster to load stuff 
-from cache then to read it from disk.
+Scaffold provides two caching engines, they are L<Scaffold::Cache::FastMmap|Scaffold::Cache::FastMmap>
+and L<Scaffold::Cache::Memcached|Scaffold::Cache::Memcached>. This module
+defines the stanadard api that the engines need to implement. 
 
-Scaffold provides two caching engines, they are Scaffold::Cache::FastMmap and
-Scaffold::Cache::Memcached.
+L<Scaffold::Cache::Manager|Scaffold::Cache::Manager> is used to maintain the
+caching subsystem. It is implemented as a plugin. 
 
-Since these caching systems use a flat, shared environment, with key, 
-value pairs for data storarge and retrieval, a "namespace" is defined to help
-differated the "key" from other similar keys. This name space can be used to
-define a flat naming scheme or even a hirearchal scheme, the choice is yours.
-The "namespace" is prepended to the "key", so a key of "junk" would be 
-presented to the caching system as "scaffold:junk".
+Since the cache can be shared between multiple processes, a "name space" 
+is defined to help differate between those processes cache usage. By default 
+this is "scaffold". It can be changed at any time with the namespace() 
+method or upon initialization of the engine.
+
+When Scaffold initializes itself, it looks for the "cache" config stanzia. 
+If one is defined than that is used for the caching engine, otherwise it
+will use Scaffold::Cache::FastMmap.
 
 =head1 METHODS
 
 =over 4
 
-=item get
+=item get(key)
 
 This method will retrieve the "value" associated with "key".
 
  $value = $self->scaffold->cache->get('junk');
 
-=item set
+=item set(key, value)
 
 This method will store the "value" associated with "key".
 
  $self->scaffold->cache->set('junk', $value);
 
-=item delete
+=item delete(key)
 
 This method will delete the "key" from the caching system.
 
  $self->scaffold->cache->delete('junk');
 
-=item update
+=item update(key, value)
 
 This method will update the "value" associated with "key". Most of the 
 caching systems do this in a "atomic" fashion.
 
  $self->scaffold->cache->update('junk', $newvalue);
 
-=item clear
+=item clear()
 
 This method will clear all items from the cache. Use with care.
 
  $self->scaffold->cache->clear();
 
-=item purge
+=item purge()
 
 This method will purge expired items out of the cache. 
 
  $self->scaffold->cache->purge();
 
-=item namespace
+=item namespace(name)
 
 This method will get/set the current namespace for cache operations.
 
@@ -188,6 +187,7 @@ This method will get/set the current namespace for cache operations.
  Scaffold::Render
  Scaffold::Render::Default
  Scaffold::Render::TT
+ Scaffold::Routes
  Scaffold::Server
  Scaffold::Session::Manager
  Scaffold::Stash
@@ -207,7 +207,7 @@ This method will get/set the current namespace for cache operations.
 
 =head1 AUTHOR
 
-Kevin L. Esteb, E<lt>kesteb@wsipc.orgE<gt>
+Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
